---
annotations_creators:
- found
language_creators:
- found
languages:
  de-en_GB:
  - de
  - en_GB
  de-es:
  - de
  - es
  de-fr:
  - de
  - fr
  de-ja:
  - de
  - ja
  de-ru:
  - de
  - ru
  de-sv:
  - de
  - sv
  de-zh_CN:
  - de
  - zh_CN
  en_GB-es:
  - en_GB
  - es
  en_GB-fr:
  - en_GB
  - fr
  en_GB-ja:
  - en_GB
  - ja
  en_GB-ru:
  - en_GB
  - ru
  en_GB-sv:
  - en_GB
  - sv
  en_GB-zh_CN:
  - en_GB
  - zh_CN
  es-fr:
  - es
  - fr
  es-ja:
  - es
  - ja
  es-ru:
  - es
  - ru
  es-sv:
  - es
  - sv
  es-zh_CN:
  - es
  - zh_CN
  fr-ja:
  - fr
  - ja
  fr-ru:
  - fr
  - ru
  fr-sv:
  - fr
  - sv
  fr-zh_CN:
  - fr
  - zh_CN
  ja-ru:
  - ja
  - ru
  ja-sv:
  - ja
  - sv
  ja-zh_CN:
  - ja
  - zh_CN
  ru-sv:
  - ru
  - sv
  ru-zh_CN:
  - ru
  - zh_CN
  sv-zh_CN:
  - sv
  - zh_CN
licenses:
- unknown
multilinguality:
- multilingual
size_categories:
- 10K<n<100K
source_datasets:
- original
task_categories:
- conditional-text-generation
task_ids:
- machine-translation
paperswithcode_id: null
pretty_name: OpusOpenoffice
---

# Dataset Card for [Dataset Name]

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks and Leaderboards](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-fields)
  - [Data Splits](#data-splits)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:**[OpenOffice](http://opus.nlpl.eu/OpenOffice.php)
- **Repository:**
- **Paper:**
- **Leaderboard:**
- **Point of Contact:**

### Dataset Summary

A collection of documents from http://www.openoffice.org/.
8 languages, 28 bitexts

### Supported Tasks and Leaderboards

The underlying task is machine translation.

### Languages

[More Information Needed]

## Dataset Structure

### Data Instances

[More Information Needed]

### Data Fields

[More Information Needed]

### Data Splits

[More Information Needed]

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

```
@InProceedings{TIEDEMANN12.463,
  author = {J�rg Tiedemann},
  title = {Parallel Data, Tools and Interfaces in OPUS},
  booktitle = {Proceedings of the Eight International Conference on Language Resources and Evaluation (LREC'12)},
  year = {2012},
  month = {may},
  date = {23-25},
  address = {Istanbul, Turkey},
  editor = {Nicoletta Calzolari (Conference Chair) and Khalid Choukri and Thierry Declerck and Mehmet Ugur Dogan and Bente Maegaard and Joseph Mariani and Jan Odijk and Stelios Piperidis},
  publisher = {European Language Resources Association (ELRA)},
  isbn = {978-2-9517408-7-7},
  language = {english}
 }
```
### Contributions

Thanks to [@patil-suraj](https://github.com/patil-suraj) for adding this dataset.
